  /**
   * Creates a [Alert Rule Model]
   * to be added in Grafana Alert Rule section
   *
   *
   * @param refId:  The unique reference ID for the query used in the alert rule. if the "refId" field is set to "B", which is used to reference this query in other parts of the alert rule.
   * @param from: This field specifies the time range for the alert query, relative to the current time. In this case, the value of 600 means that the query should retrieve data from 600 seconds (10 minutes) ago to the current time.
   * @param to: This field specifies the end time of the alert query relative to the current time. In this case, the value of 0 means that the end time of the query is the current time.
   * @param datasourceUid:  This field in the alert rule model specifies the unique identifier of the data source that the query for the alert is going to be executed on.
   * @param editorMode: This field specifies the mode in which the query was created. In this case, it is "code" mode, which means that the query was written using the query language
   * @param expr: Query expression to be run on the alert rule
   * @param expression: This field specifies the name of the query that should be evaluated to determine if the alert condition is met. The query can be specified using either the query editor or the code editor in Grafana. The value of the "expression" field is "A", which means that the query with the reference ID "A" will be evaluated to determine if the alert condition is met.
   * @param hide: Whether or not to show the result of the alert evaluation in the panel. In this example, it's set to false
   * @param intervalMs: The interval at which to evaluate the alert. In this example, it's set to 1000 milliseconds.
   * @param legendFormat: (optional) Set to `true` to hide the target from the panel.
   * @param maxDataPoints: The maximum number of data points to retrieve for the query. In this example, it's set to 43200.
   * @param range: This field specifies whether the query should include the time range in the query. If set to "true", the query will return data points within the specified time range.
   * @param type: The type of the query. In this example, it's a "reduce" query.
   * @param modelCondition: (optional)  A list of conditions that must be met for the alert to trigger. In this example, there is only one condition that checks whether the value of the query result is greater than a certain threshold.
   * @param reducer: The method used to reduce the time series data before performing the evaluation. In this example, it's the "count" method.
   
   * @return A Alert Model to be added in Alert-Rule.
   */
{

  new(
    refId,
    from,
    to,
    datasourceUid=null,
    editorMode=null,
    expr=null,
    expression=null,
    hide=null,
    intervalMs,
    legendFormat=null,
    maxDataPoints,
    range=null,
    type=null,
    modelCondition=null,
    reducer=null
  ):: {
    refId: refId,
    relativeTimeRange: {
        from: from,
        to: to
    },
    datasourceUid: datasourceUid,
    model: {
        [if editorMode != null then 'editorMode']: editorMode,
        [if expr != null then 'expr']: expr,
        hide: hide,
        intervalMs: intervalMs,
        [if legendFormat != null then 'legendFormat']: legendFormat,
        maxDataPoints: maxDataPoints,
        [if modelCondition != null then 'conditions']: [modelCondition],
        [if range != null then 'range']: range,
        refId: refId,
        [if reducer != null then 'reducer']: reducer,
        [if type != null then 'type']: type,
        [if expression != null then 'expression']: expression,
   [if refId != 'A' then 'datasource']:
        if refId != 'A' then
        {
          type: "__expr__",
          uid: "__expr__"
        }
        else
        null,
    },
  },
}
